==> pyviz_comms-3.0.1.tar.gz: pyviz_comms-3.0.1/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 3.0.1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.0...e7ed26085532186997707a5debc4ddd6a9be6685))

### Merged PRs

- Add save handler for Panel Layout Builder [#120](https://github.com/holoviz/pyviz_comms/pull/120) ([@philippjfr](https://github.com/philippjfr))
- Publish again to the `pyviz` channel [#117](https://github.com/holoviz/pyviz_comms/pull/117) ([@maximlt](https://github.com/maximlt))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-08-16&to=2024-01-15&type=c))

[@maximlt](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Amaximlt+updated%3A2023-08-16..2024-01-15&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-08-16..2024-01-15&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 3.0.0

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)

## 3.0.0a3

No merged PRs

## 3.0.0a2

No merged PRs

## 3.0.0a1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)

==> pyviz_comms-3.0.2.tar.gz: pyviz_comms-3.0.2/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 3.0.2

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.1...ec9873fba879d232ea7072d0bead9c6f48686296))

### Merged PRs

- Ensure save handler gracefully handles undefined layout data [#121](https://github.com/holoviz/pyviz_comms/pull/121) ([@philippjfr](https://github.com/philippjfr))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2024-01-15&to=2024-03-21&type=c))

[@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2024-01-15..2024-03-21&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 3.0.1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v3.0.0...e7ed26085532186997707a5debc4ddd6a9be6685))

### Merged PRs

- Add save handler for Panel Layout Builder [#120](https://github.com/holoviz/pyviz_comms/pull/120) ([@philippjfr](https://github.com/philippjfr))
- Publish again to the `pyviz` channel [#117](https://github.com/holoviz/pyviz_comms/pull/117) ([@maximlt](https://github.com/maximlt))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-08-16&to=2024-01-15&type=c))

[@maximlt](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Amaximlt+updated%3A2023-08-16..2024-01-15&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-08-16..2024-01-15&type=Issues)

## 3.0.0

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)

## 3.0.0a3

No merged PRs

## 3.0.0a2

No merged PRs

## 3.0.0a1

([Full Changelog](https://github.com/holoviz/pyviz_comms/compare/v2.3.2...efc455dc826e73216e7da293d7cd2ee1155d3ada))

### Enhancements made

- Update to JupyterLab 4 [#114](https://github.com/holoviz/pyviz_comms/pull/114) ([@andrewfulton9](https://github.com/andrewfulton9))

### Other merged PRs

- pip downstream dependency to fix build error [#113](https://github.com/holoviz/pyviz_comms/pull/113) ([@andrewfulton9](https://github.com/andrewfulton9))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/holoviz/pyviz_comms/graphs/contributors?from=2023-06-15&to=2023-08-16&type=c))

[@andrewfulton9](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aandrewfulton9+updated%3A2023-06-15..2023-08-16&type=Issues) | [@philippjfr](https://github.com/search?q=repo%3Aholoviz%2Fpyviz_comms+involves%3Aphilippjfr+updated%3A2023-06-15..2023-08-16&type=Issues)
